@@ -1,3 +1,13 @@
+"""
+aspen.context
++++++++++++++
+"""
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
+
 class Context(dict):
     """Model the execution context for a Resource.
     """
@@ -12,12 +22,11 @@ class Context(dict):
         self.path       = request.line.uri.path
         self.qs         = request.line.uri.querystring
         self.request    = request
-        self.socket     = None
         self.channel    = None
         self.context    = self
 
         # http://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html
-        for method in ['OPTIONS', 'GET', 'HEAD', 'POST', 'PUT', 'DELETE', 
+        for method in ['OPTIONS', 'GET', 'HEAD', 'POST', 'PUT', 'DELETE',
                        'TRACE', 'CONNECT']:
             self[method] = (method == request.line.method)
             setattr(self, method, self[method])
